@@ -828,7 +828,7 @@ class PeerManager:
 # Ogni nuova connessione viene assegnata ad un oggetto TorrentPeer,
 # il quale si occuperà di gestire lo scambio di messaggi
 class ThreadedServer:
-    def __init__(self, port, metainfo, tracker_manager, **options):
+    def __init__(self, metainfo, tracker_manager, **options):
         self.host = "localhost"
         self.peer = None
         self.options = options
@@ -839,6 +839,7 @@ class ThreadedServer:
         self.metainfo = metainfo
         self.tracker_manager = tracker_manager
 
+        port = options["port"]
         self.logger.debug("Server is binding at %s", (self.host, port))
         
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -848,8 +849,6 @@ class ThreadedServer:
         self.port = self.sock.getsockname()[1]
         self.logger.debug("Self port: %d", self.port)
 
-        self.options = options
-
         self.peers = list()
         peers = self.tracker_manager.notify_start()
         for ip, pport in peers:
